@@ -20,7 +20,7 @@ from ..utils import (
     get_default_layouts,
     effect,
 )
-from ..jax_compat import hlo_custom_call
+from ..jax_compat import hlo_custom_call, token_type
 from ..decorators import translation_rule_cpu, translation_rule_gpu
 from ..validation import enforce_types
 from ..comm import get_default_comm
@@ -94,7 +94,7 @@ def mpi_allreduce_xla_encode_cpu(ctx, x, token, op, comm, transpose):
 
     out_types = [
         ir.RankedTensorType.get(dims, dtype),
-        *mlir.token_type(),
+        *token_type(),
     ]
 
     operands = (
@@ -139,7 +139,7 @@ def mpi_allreduce_xla_encode_gpu(ctx, x, token, op, comm, transpose):
 
     out_types = [
         ir.RankedTensorType.get(dims, dtype),
-        *mlir.token_type(),
+        *token_type(),
     ]
 
     operands = (
