@@ -19,7 +19,7 @@ from ..utils import (
     get_default_layouts,
     effect,
 )
-from ..jax_compat import hlo_custom_call
+from ..jax_compat import hlo_custom_call, token_type
 from ..decorators import translation_rule_cpu, translation_rule_gpu
 from ..validation import enforce_types
 from ..comm import get_default_comm
@@ -98,7 +98,7 @@ def mpi_bcast_xla_encode_cpu(ctx, x, token, root, comm):
 
     out_types = [
         ir.RankedTensorType.get(dims, dtype),
-        *mlir.token_type(),
+        *token_type(),
     ]
 
     operands = (
@@ -144,7 +144,7 @@ def mpi_bcast_xla_encode_gpu(ctx, x, token, root, comm):
 
     out_types = [
         ir.RankedTensorType.get(dims, dtype),
-        *mlir.token_type(),
+        *token_type(),
     ]
 
     operands = (
