@@ -7,7 +7,6 @@ from jax.lax import create_token
 
 from jax.interpreters import mlir
 import jaxlib.mlir.ir as ir
-from jaxlib.mhlo_helpers import custom_call
 
 from ..utils import (
     HashableMPIType,
@@ -20,6 +19,7 @@ from ..utils import (
     get_default_layouts,
     effect,
 )
+from ..jax_compat import hlo_custom_call, token_type
 from ..decorators import translation_rule_cpu, translation_rule_gpu
 from ..validation import enforce_types
 from ..comm import get_default_comm
@@ -78,7 +78,7 @@ def mpi_send_xla_encode_cpu(ctx, x, token, dest, tag, comm):
     nitems = _np.prod(dims, dtype=int)
     dtype_handle = to_dtype_handle(x_nptype)
 
-    out_types = mlir.token_type()
+    out_types = token_type()
 
     operands = (
         as_mhlo_constant(nitems, _np.intc),
@@ -92,7 +92,7 @@ def mpi_send_xla_encode_cpu(ctx, x, token, dest, tag, comm):
 
     # JAX insists on outputs being iterable
     return [
-        custom_call(
+        hlo_custom_call(
             b"mpi_send",
             out_types=out_types,
             operands=operands,
@@ -119,7 +119,7 @@ def mpi_send_xla_encode_gpu(ctx, x, token, dest, tag, comm):
     nitems = _np.prod(dims, dtype=int)
     dtype_handle = to_dtype_handle(x_nptype)
 
-    out_types = mlir.token_type()
+    out_types = token_type()
 
     operands = (
         x,
@@ -136,7 +136,7 @@ def mpi_send_xla_encode_gpu(ctx, x, token, dest, tag, comm):
 
     # JAX insists on outputs being iterable
     return [
-        custom_call(
+        hlo_custom_call(
             b"mpi_send",
             out_types=out_types,
             operands=operands,
